@@ -116,7 +116,8 @@ locus family.'''
             rootOfLfSubtree = self.reconRootKey[0]
             lfSubtreeO = fam.geneTreeO.subtree(rootOfLfSubtree)
             fam.printReconByGeneTreeHelper(fam.dtlorMprD,lfSubtreeO,genesO,self.reconRootKey[0],0,fileF)
-        #self,dtlorMprD,geneRtreeO,genesO,node,level,fileF=sys.stdout    
+        #self,dtlorMprD,geneRtreeO,genesO,node,level,fileF=sys.stdout
+        
     def getStr(self,genesO,sep):
         '''Return a string representation of a single LocusFamily. Separator
 between elements given by sep. Elements are: locusFamNum lfMrca gene1
@@ -652,10 +653,14 @@ geneTreeNode. eventType is a string, D T L O R.'''
             eventCtr = 0
             for child in self.geneTreeO.children(geneTreeNode):
                 # count on child branch, then recurse
+                eventValueL = []
                 if (child,'b') in self.dtlorMprD:
-                    for eventValue in self.dtlorMprD[(child,'b')]:
-                        if eventValue[0] == eventType:
-                            eventCtr += 1
+                    eventValueL.extend(self.dtlorMprD[(child,'b')])
+                if (child,'n') in self.dtlorMprD:
+                    eventValueL.extend(self.dtlorMprD[(child,'n')])
+                for eventValue in eventValueL:
+                    if eventValue[0] == eventType:
+                        eventCtr += 1
                 eventCtr += self.countEventsBelowNode(child,eventType)
             return eventCtr
 
@@ -683,7 +688,7 @@ geneTreeNode. eventType is a string, D T L O R.'''
                 dtlorScore += self.dtlorScoreBelowNode(paramD,child)
             return dtlorScore
         
-    def getNewickGeneTreeWithReconLabels(self,genesO):
+    def getNewickGeneTreeWithReconLabels(self,genesO,includeBrLength=False):
         '''Print out a Newick string where the nodes are labeled with
 events. Format for annotations are [branch events | node events ]. For
 tips on the gene tree, the "node event" is the species it ends up
@@ -711,7 +716,7 @@ in.
             nodeLabelD[node] = nodeStr
 
         # put in newick string
-        return self.geneTreeO.toNewickStr(nodeLabelD=nodeLabelD)
+        return self.geneTreeO.toNewickStr(includeBrLength=includeBrLength,nodeLabelD=nodeLabelD)
 
 class Families:
 
