@@ -12,7 +12,7 @@ class Score:
         self.strainPairScoreLocationD = {}
         self.scoreD = {}
 
-    def initializeDataAttributes(self,blastFnL,paramD,strainNamesT):
+    def initializeDataAttributes(self,blastFnL,paramD,strainNamesT,genesO):
         '''This method takes a new, empty object and fills the data attributes
 by reading through blast files to identify pairs of genes with
 edges. Also creates the array for storing raw scores, initialized to
@@ -20,11 +20,11 @@ edges. Also creates the array for storing raw scores, initialized to
 included here depend on what is found in the blast files in blastFnL.
 
         '''
-        self.fillEndNodesToEdgeD(blastFnL,paramD,strainNamesT)
+        self.fillEndNodesToEdgeD(blastFnL,paramD,strainNamesT,genesO)
         self.numEdges=len(self.endNodesToEdgeD)
         self.initializeScoreArray('rawSc')
 
-    def fillEndNodesToEdgeD(self,blastFnL,paramD,strainNamesT):
+    def fillEndNodesToEdgeD(self,blastFnL,paramD,strainNamesT,genesO):
         '''Run through blast files, finding all pairs of genes with signicant
 similarity. Use these to fill endNodesToEdgeD. Also keep track of the
 edge numbers associated with particular strain pairs and save in
@@ -39,7 +39,15 @@ strainPairScoreLocationD.
         
         blastFnByPairD = self.getBlastFnByPairD(blastFnL,blastFileJoinStr,strainNamesT)
 
+        # get edges
         edgeNum=0
+        for g in genesO.iterGenes(): # first every gene vs itself
+            if genesO.numToStrainName(g) in strainNamesT:
+                # but only do it for genes that occur in a strain in strainNamesT
+                self.endNodesToEdgeD[(g,g)] = edgeNum
+                edgeNum += 1
+            
+        # now get edges out of blast files
         for strainPair in blastFnByPairD:
             pairT = blastFnByPairD[strainPair]
             
@@ -50,7 +58,7 @@ strainPairScoreLocationD.
             # and also for 2 vs 1), or may only have one (e.g. for
             # strain 1 vs strain 1).
             for fn in pairT:
-                for g1,g2,evalue,alCov,pident,score in blast.parseBlastFile(fn,evalueThresh,alignCoverThresh,percIdentThresh):
+                for g1,g2,evalue,alCov,pident,score,alLen in blast.parseBlastFile(fn,evalueThresh,alignCoverThresh,percIdentThresh):
                     
                     # because we have blast files going both ways
                     # (e.g. strain 1 vs strain 2 and also strain 2 vs
@@ -406,7 +414,7 @@ will be used (e.g. in family formation).
         if gene in self.nodeConnectD:
             return self.nodeConnectD[gene]
         else:
-            return None
+            return []
         
     def createNodeEdgeL(self,geneNamesO):
         '''Create an attribute nodeEdgeL. Index in this list corresponds to
